@@ -53,7 +53,7 @@ class TagManager(BaseManager):
                                                object_id=obj.pk,
                                                tag__in=tags_for_removal).delete()
         # Add new tags
-        current_tag_names = [tag.name for tag in current_tags]
+        current_tag_names = [tag.name_any for tag in current_tags]
         for tag_name in updated_tag_names:
             if tag_name not in current_tag_names:
                 tag, created = self.get_or_create(name=tag_name)
@@ -349,6 +349,7 @@ class TagManager(BaseManager):
 
     def join(self, query):
         """This method joins multiple tags together."""
+        from tagging.utils import merge
 
         logger.info('Joining %s' % ','.join([unicode(obj) for obj in query]))
         tags = list(query)
@@ -357,18 +358,9 @@ class TagManager(BaseManager):
 
         first = tags[0]
         tags = tags[1:]
+        for t in tags:
+            merge(first, t)
 
-        objects_with_first = [tag.object for tag in TaggedItem.objects.filter(tag=first)]
-        tagged_items = TaggedItem.objects.filter(tag__in=tags)
-        for item in tagged_items:
-            if item.object in objects_with_first:
-                item.delete()
-            else:
-                item.tag = first
-                item.save()
-
-        for tag in tags:
-            tag.delete()
 
 class TaggedItemManager(models.Manager):
     """
@@ -633,7 +625,7 @@ class TaggedItem(models.Model):
 
     def _updateLinkedObjects(self, remove_this = False):
         from tagging.fields import TagField
-        object_tags = [ tag.name \
+        object_tags = [ tag.name_any \
                       for tag in Tag.objects.get_for_object(self.object) \
                               if not remove_this or tag.id != self.tag_id ]
         tags_as_string = ', '.join(object_tags)
